require 'sinatra'
require 'json'
require 'json-schema'
require_relative 'pragmatic_segmenter_server/segment'


post '/segment' do
	content_type :json

	# Input 
	input = JSON.parse(request.body.read)
	
	schema = {
			"type" => "object",
			"required" => ["texts", "lang"],
			"properties" => {
				"texts"  => {
					"type" => "array",
					"items": {
						"type": "string",
						"minItems": 1
					}
				},
				"lang"  => {
					"type" => "string"
				},
				"segmentByNewline" => {
					"type" => "boolean"
				}
			}  
		}

	begin	
		JSON::Validator.validate!(schema, input)
	rescue JSON::Schema::ValidationError => e
		json_message = {"error":e.message}.to_json
		status 400
		body json_message
		return
	end

	# Extract info
	lang = input["lang"]
	texts =  input["texts"]

	if !input.key?("segmentByNewline")
		segmentByNewline = true
	else
		segmentByNewline = input["segmentByNewline"]
	end

		
	# Segmentation
	results = []
	texts.each do |text, index|
		segments, mask = segment(text, lang, segmentByNewline)
		results.push({
			"text": text,
			"segments": segments,
			"mask": mask
		})
	end

	results.to_json
end
